@@ -45,9 +45,9 @@ pub mod prelude {
     //! ```
 
     pub use super::contract::contract::Contract;
-    pub use super::contract::parameters::*;
     pub use super::core::constants::*;
     pub use super::core::errors::Error;
+    pub use super::core::parameters::*;
     pub use super::core::{Token, Tokenizable};
     pub use super::signers::provider::*;
     pub use super::signers::{LocalWallet, Signer};
